Crate anchor_derive_serde

Crate anchor_derive_serde 

Defines the AnchorSerialize and AnchorDeserialize derive macros These emit a BorshSerialize/BorshDeserialize implementation for the given type, as well as emitting IDL type information when the idl-build feature is enabled.

Derive Macros

AnchorDeserialize
Implements borsh deserialization for this structure, as well as implementing lazy deserialization if the lazy-account feature is enabled. #[borsh(use_discriminant = false)] is supported with lazy-account; use_discriminant = true and other #[borsh] attributes (e.g. skip) are not yet supported in conjunction with lazy-account.
AnchorSerialize